@@ -105,6 +105,14 @@ create_stacked <- function(data,
   data %>%
     check_inputs(requirements = required_variables)
 
+  ## Plot Title Handling
+  if(is(object = metrics, class2 = "character") & length(metrics) == 1){
+    plot_title <- us_to_space(metrics)
+  }
+  else{   #vector of strings
+    plot_title <- paste(plot_title, collapse = ", ")
+  }
+
   ## Handle `legend_lab`
   if(is.null(legend_lab)){
     legend_lab <- gsub("_", " ", metrics)
